@@ -36,8 +36,8 @@ static ON_STARTUP_DEBUG_ONCE: Once = Once::new();
 
 impl ExeMeta {
     #[allow(clippy::wrong_self_convention)]
-    fn from_global_path(&self) -> Option<PathBuf> {
-        which::which(self.name).ok()
+    fn from_global_path(name: &str) -> Option<PathBuf> {
+        which::which(name).ok()
     }
 
     fn get_name(&self) -> String {
@@ -219,20 +219,23 @@ pub enum Exe<'a> {
 
 impl Exe<'_> {
     pub async fn get(&self) -> Result<PathBuf> {
-        let meta = self.meta().await?;
+        let name = self.name();
+        let mut version = String::from("{unknown version}");
 
-        let path = if let Some(path) = meta.from_global_path() {
+        let path = if let Some(path) = ExeMeta::from_global_path(name) {
             path
         } else if cfg!(feature = "no_downloads") {
-            bail!("{} is required but was not found. Please install it using your OS's tool of choice", &meta.name);
+            bail!("{} is required but was not found. Please install it using your OS's tool of choice", &name);
         } else {
+            let meta = self.meta().await?;
+            version = meta.version.clone();
             meta.cached().await.wrap_err(meta.manual)?
         };
 
         debug!(
             "Command using {} {} {}",
-            &meta.name,
-            &meta.version,
+            name,
+            version,
             GRAY.paint(path.to_string_lossy())
         );
 
@@ -240,7 +243,10 @@ impl Exe<'_> {
     }
 
     pub async fn meta(&self) -> Result<ExeMeta> {
-        let (target_os, target_arch) = os_arch().unwrap();
+        let Ok((target_os, target_arch)) = os_arch() else {
+            bail!("{} is required but was not found, and downloads are not supported on this platform. \
+            Please install it using your OS's tool of choice", &self.name());
+        };
 
         let exe = match self {
             Exe::Sass => CommandSass.exe_meta(target_os, target_arch).await.dot()?,
@@ -260,6 +266,15 @@ impl Exe<'_> {
 
         Ok(exe)
     }
+
+    fn name(&self) -> &str {
+        match self {
+            Exe::Sass => CommandSass.name(),
+            Exe::Tailwind => CommandTailwind.name(),
+            Exe::WasmOpt => CommandWasmOpt.name(),
+            Exe::WasmBindgen { project_root } => CommandWasmBindgen { project_root }.name(),
+        }
+    }
 }
 
 /// Tailwind uses the 'vMaj.Min.Pat' format.
@@ -441,13 +456,13 @@ impl Command for CommandSass {
             match target_arch {
                 "x86_64" => {
                     format!(
-                        "https://github.com/{}/{}/releases/download/{}/dart-sass-{}-linux-x64.tar.gz",
+                        "https://github.com/{}/{}/releases/download/{}/dart-sass-{}-linux-x64-musl.tar.gz",
                         self.github_owner(), self.github_repo(), version, version
                     )
                 }
                 "aarch64" => {
                     format!(
-                        "https://github.com/{}/{}/releases/download/{}/dart-sass-{}-linux-arm64.tar.gz"
+                        "https://github.com/{}/{}/releases/download/{}/dart-sass-{}-linux-arm64-musl.tar.gz"
                         , self.github_owner(), self.github_repo(), version, version
                     )
                 }
